diff --git a/README.md b/README.md
index 01442cae798..fe6684354aa 100644
--- a/README.md
+++ b/README.md
@@ -30,8 +30,8 @@ This code is automatically generated by the [OpenAPI Generator](https://openapi-
## Versions
-- API version: 0.11.7201
-- SDK version: 2.0.1281
+- API version: 0.11.7203
+- SDK version: 2.0.1282
## Requirements
@@ -47,7 +47,7 @@ Add this dependency to your pom.xml
com.finbourne
lusid-sdk
- 2.0.1281
+ 2.0.1282
```
@@ -61,7 +61,7 @@ Add this dependency to your build.gradle
}
dependencies {
- implementation "com.finbourne:lusid-sdk:2.0.1281"
+ implementation "com.finbourne:lusid-sdk:2.0.1282"
}
```
diff --git a/sdk/api/openapi.yaml b/sdk/api/openapi.yaml
index 8e2d67a5d19..3eb5b11920d 100644
--- a/sdk/api/openapi.yaml
+++ b/sdk/api/openapi.yaml
@@ -381,7 +381,7 @@ info:
| 938|The new Closed Period would cause the Timeline to have non-contiguous Closed Periods| |
termsOfService: https://www.finbourne.com/legal/terms-conditions
title: LUSID API
- version: 0.11.7201
+ version: 0.11.7203
x-logo:
url: https://www.lusid.com/app/assets/logo_white.png
backgroundColor: '#415464'
@@ -125093,11 +125093,12 @@ components:
type: boolean
type:
description: "The type of the portfolio. The available values are: Transaction,\
- \ Reference, DerivedTransaction"
+ \ Reference, DerivedTransaction, SimplePosition"
enum:
- Transaction
- Reference
- DerivedTransaction
+ - SimplePosition
type: string
version:
$ref: '#/components/schemas/Version'
@@ -169730,11 +169731,12 @@ components:
$ref: '#/components/schemas/ResourceId'
type:
description: "The type of the portfolio. The available values are: Transaction,\
- \ Reference, DerivedTransaction"
+ \ Reference, DerivedTransaction, SimplePosition"
enum:
- Transaction
- Reference
- DerivedTransaction
+ - SimplePosition
type: string
displayName:
description: The name of the portfolio.
@@ -172408,11 +172410,12 @@ components:
$ref: '#/components/schemas/ResourceId'
type:
description: "The type of the portfolio. The available values are: Transaction,\
- \ Reference, DerivedTransaction"
+ \ Reference, DerivedTransaction, SimplePosition"
enum:
- Transaction
- Reference
- DerivedTransaction
+ - SimplePosition
type: string
href:
description: The specific Uniform Resource Identifier (URI) for this resource
@@ -172587,6 +172590,7 @@ components:
- Transaction
- Reference
- DerivedTransaction
+ - SimplePosition
type: string
PortfolioWithoutHref:
additionalProperties: false
@@ -172767,11 +172771,12 @@ components:
$ref: '#/components/schemas/ResourceId'
type:
description: "The type of the portfolio. The available values are: Transaction,\
- \ Reference, DerivedTransaction"
+ \ Reference, DerivedTransaction, SimplePosition"
enum:
- Transaction
- Reference
- DerivedTransaction
+ - SimplePosition
type: string
displayName:
description: The name of the portfolio.
diff --git a/sdk/docs/CompletePortfolio.md b/sdk/docs/CompletePortfolio.md
index 2f4640edd41..d554b1e4bfe 100644
--- a/sdk/docs/CompletePortfolio.md
+++ b/sdk/docs/CompletePortfolio.md
@@ -14,7 +14,7 @@
|**created** | **OffsetDateTime** | The effective datetime at which the portfolio was created. No transactions or constituents can be added to the portfolio before this date. | [optional] |
|**parentPortfolioId** | [**ResourceId**](ResourceId.md) | | [optional] |
|**isDerived** | **Boolean** | Whether or not this is a derived portfolio. | [optional] [readonly] |
-|**type** | [**TypeEnum**](#TypeEnum) | The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction | [optional] |
+|**type** | [**TypeEnum**](#TypeEnum) | The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition | [optional] |
|**version** | [**Version**](Version.md) | | |
|**properties** | [**List<Property>**](Property.md) | The requested portfolio properties. These will be from the 'Portfolio' domain. | [optional] |
|**baseCurrency** | **String** | If the portfolio is a transaction portfolio or derived transaction portfolio, this is the base currency of the portfolio. | [optional] |
@@ -30,6 +30,7 @@
| TRANSACTION | "Transaction" |
| REFERENCE | "Reference" |
| DERIVEDTRANSACTION | "DerivedTransaction" |
+| SIMPLEPOSITION | "SimplePosition" |
diff --git a/sdk/docs/Portfolio.md b/sdk/docs/Portfolio.md
index 82e359fc3d4..b07c9849d6f 100644
--- a/sdk/docs/Portfolio.md
+++ b/sdk/docs/Portfolio.md
@@ -10,7 +10,7 @@ A list of portfolios.
|------------ | ------------- | ------------- | -------------|
|**href** | **URI** | The specific Uniform Resource Identifier (URI) for this resource at the requested effective and asAt datetime. | [optional] |
|**id** | [**ResourceId**](ResourceId.md) | | |
-|**type** | [**TypeEnum**](#TypeEnum) | The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction | |
+|**type** | [**TypeEnum**](#TypeEnum) | The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition | |
|**displayName** | **String** | The name of the portfolio. | |
|**description** | **String** | The long form description of the portfolio. | [optional] |
|**created** | **OffsetDateTime** | The effective datetime at which the portfolio was created. No transactions or constituents can be added to the portfolio before this date. | |
@@ -39,6 +39,7 @@ A list of portfolios.
| TRANSACTION | "Transaction" |
| REFERENCE | "Reference" |
| DERIVEDTRANSACTION | "DerivedTransaction" |
+| SIMPLEPOSITION | "SimplePosition" |
diff --git a/sdk/docs/PortfolioSearchResult.md b/sdk/docs/PortfolioSearchResult.md
index a707a273a5f..e963120ceeb 100644
--- a/sdk/docs/PortfolioSearchResult.md
+++ b/sdk/docs/PortfolioSearchResult.md
@@ -9,7 +9,7 @@ A list of portfolios.
| Name | Type | Description | Notes |
|------------ | ------------- | ------------- | -------------|
|**id** | [**ResourceId**](ResourceId.md) | | |
-|**type** | [**TypeEnum**](#TypeEnum) | The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction | |
+|**type** | [**TypeEnum**](#TypeEnum) | The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition | |
|**href** | **URI** | The specific Uniform Resource Identifier (URI) for this resource at the requested effective and asAt datetime. | [optional] |
|**description** | **String** | The long form description of the portfolio. | [optional] |
|**displayName** | **String** | The name of the portfolio. | |
@@ -29,6 +29,7 @@ A list of portfolios.
| TRANSACTION | "Transaction" |
| REFERENCE | "Reference" |
| DERIVEDTRANSACTION | "DerivedTransaction" |
+| SIMPLEPOSITION | "SimplePosition" |
diff --git a/sdk/docs/PortfolioType.md b/sdk/docs/PortfolioType.md
index 5edbea2e727..8d005c29ee9 100644
--- a/sdk/docs/PortfolioType.md
+++ b/sdk/docs/PortfolioType.md
@@ -11,6 +11,8 @@
* `DERIVEDTRANSACTION` (value: `"DerivedTransaction"`)
+* `SIMPLEPOSITION` (value: `"SimplePosition"`)
+
[Back to Model list](../README.md#documentation-for-models) • [Back to API list](../README.md#documentation-for-api-endpoints) • [Back to README](../README.md)
diff --git a/sdk/docs/PortfolioWithoutHref.md b/sdk/docs/PortfolioWithoutHref.md
index 6f2c449c0d1..51aee4b0f6f 100644
--- a/sdk/docs/PortfolioWithoutHref.md
+++ b/sdk/docs/PortfolioWithoutHref.md
@@ -9,7 +9,7 @@ A list of portfolios.
| Name | Type | Description | Notes |
|------------ | ------------- | ------------- | -------------|
|**id** | [**ResourceId**](ResourceId.md) | | |
-|**type** | [**TypeEnum**](#TypeEnum) | The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction | |
+|**type** | [**TypeEnum**](#TypeEnum) | The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition | |
|**displayName** | **String** | The name of the portfolio. | |
|**description** | **String** | The long form description of the portfolio. | [optional] |
|**created** | **OffsetDateTime** | The effective datetime at which the portfolio was created. No transactions or constituents can be added to the portfolio before this date. | |
@@ -38,6 +38,7 @@ A list of portfolios.
| TRANSACTION | "Transaction" |
| REFERENCE | "Reference" |
| DERIVEDTRANSACTION | "DerivedTransaction" |
+| SIMPLEPOSITION | "SimplePosition" |
diff --git a/sdk/pom.xml b/sdk/pom.xml
index c8e16ac8c7f..e34b1454af4 100644
--- a/sdk/pom.xml
+++ b/sdk/pom.xml
@@ -5,7 +5,7 @@
lusid-sdk
jar
lusid-sdk
- 2.0.1281
+ 2.0.1282
https://github.com/finbourne/lusid-sdk-java
lusid
diff --git a/sdk/src/main/java/com/finbourne/lusid/ApiClient.java b/sdk/src/main/java/com/finbourne/lusid/ApiClient.java
index ef4d8ffb9e6..c21c68fc10a 100644
--- a/sdk/src/main/java/com/finbourne/lusid/ApiClient.java
+++ b/sdk/src/main/java/com/finbourne/lusid/ApiClient.java
@@ -212,7 +212,7 @@ private void init() {
json = new JSON();
// Set default User-Agent.
- setUserAgent("OpenAPI-Generator/2.0.1281/java");
+ setUserAgent("OpenAPI-Generator/2.0.1282/java");
authentications = new HashMap();
}
diff --git a/sdk/src/main/java/com/finbourne/lusid/Configuration.java b/sdk/src/main/java/com/finbourne/lusid/Configuration.java
index 13f9f045cc3..05ee9e29926 100644
--- a/sdk/src/main/java/com/finbourne/lusid/Configuration.java
+++ b/sdk/src/main/java/com/finbourne/lusid/Configuration.java
@@ -12,7 +12,7 @@
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen")
public class Configuration {
- public static final String VERSION = "2.0.1281";
+ public static final String VERSION = "2.0.1282";
private static ApiClient defaultApiClient = new ApiClient();
diff --git a/sdk/src/main/java/com/finbourne/lusid/model/PortfolioType.java b/sdk/src/main/java/com/finbourne/lusid/model/PortfolioType.java
index 2c64e6846b0..ce9523fe7e9 100644
--- a/sdk/src/main/java/com/finbourne/lusid/model/PortfolioType.java
+++ b/sdk/src/main/java/com/finbourne/lusid/model/PortfolioType.java
@@ -29,7 +29,9 @@ public enum PortfolioType {
REFERENCE("Reference"),
- DERIVEDTRANSACTION("DerivedTransaction");
+ DERIVEDTRANSACTION("DerivedTransaction"),
+
+ SIMPLEPOSITION("SimplePosition");
private String value;
diff --git a/sdk/src/main/java/com/finbourne/lusid/model/CompletePortfolio.java b/sdk/src/main/java/com/finbourne/lusid/model/CompletePortfolio.java
index 7b212304dc9..e5e9f65922a 100644
--- a/sdk/src/main/java/com/finbourne/lusid/model/CompletePortfolio.java
+++ b/sdk/src/main/java/com/finbourne/lusid/model/CompletePortfolio.java
@@ -87,7 +87,7 @@ public class CompletePortfolio {
private Boolean isDerived;
/**
* The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
*/
@JsonAdapter(TypeEnum.Adapter.class)
public enum TypeEnum {
@@ -95,7 +95,9 @@ public enum TypeEnum {
REFERENCE("Reference"),
- DERIVEDTRANSACTION("DerivedTransaction");
+ DERIVEDTRANSACTION("DerivedTransaction"),
+
+ SIMPLEPOSITION("SimplePosition");
private String value;
@@ -315,7 +317,7 @@ public CompletePortfolio type(TypeEnum type) {
}
/**
* The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
* @return type
**/
@jakarta.annotation.Nullable
@@ -87,7 +87,7 @@ public class CompletePortfolio {
private Boolean isDerived;
/**
- * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
+ * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition
*/
@@ -315,7 +317,7 @@ public CompletePortfolio type(TypeEnum type) {
}
/**
- * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
+ * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition
* @return type
**/
diff --git a/sdk/src/main/java/com/finbourne/lusid/model/Portfolio.java b/sdk/src/main/java/com/finbourne/lusid/model/Portfolio.java
index 97b8481e351..8eecfc37b40 100644
--- a/sdk/src/main/java/com/finbourne/lusid/model/Portfolio.java
+++ b/sdk/src/main/java/com/finbourne/lusid/model/Portfolio.java
@@ -72,7 +72,7 @@ public class Portfolio {
private ResourceId id;
/**
* The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
*/
@JsonAdapter(TypeEnum.Adapter.class)
public enum TypeEnum {
@@ -80,7 +80,9 @@ public enum TypeEnum {
REFERENCE("Reference"),
- DERIVEDTRANSACTION("DerivedTransaction");
+ DERIVEDTRANSACTION("DerivedTransaction"),
+
+ SIMPLEPOSITION("SimplePosition");
private String value;
@@ -323,7 +325,7 @@ public Portfolio type(TypeEnum type) {
}
/**
* The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
* @return type
**/
@jakarta.annotation.Nonnull
@@ -72,7 +72,7 @@ public class Portfolio {
private ResourceId id;
/**
- * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
+ * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition
*/
@@ -323,7 +325,7 @@ public Portfolio type(TypeEnum type) {
}
/**
- * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
+ * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition
* @return type
**/
diff --git a/sdk/src/main/java/com/finbourne/lusid/model/PortfolioSearchResult.java b/sdk/src/main/java/com/finbourne/lusid/model/PortfolioSearchResult.java
index 52718280e4f..c2c5c4f73c1 100644
--- a/sdk/src/main/java/com/finbourne/lusid/model/PortfolioSearchResult.java
+++ b/sdk/src/main/java/com/finbourne/lusid/model/PortfolioSearchResult.java
@@ -62,7 +62,7 @@ public class PortfolioSearchResult {
private ResourceId id;
/**
* The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
*/
@JsonAdapter(TypeEnum.Adapter.class)
public enum TypeEnum {
@@ -70,7 +70,9 @@ public enum TypeEnum {
REFERENCE("Reference"),
- DERIVEDTRANSACTION("DerivedTransaction");
+ DERIVEDTRANSACTION("DerivedTransaction"),
+
+ SIMPLEPOSITION("SimplePosition");
private String value;
@@ -189,7 +191,7 @@ public PortfolioSearchResult type(TypeEnum type) {
}
/**
* The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
* @return type
**/
@jakarta.annotation.Nonnull
@@ -62,7 +62,7 @@ public class PortfolioSearchResult {
private ResourceId id;
/**
- * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
+ * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition
*/
@@ -189,7 +191,7 @@ public PortfolioSearchResult type(TypeEnum type) {
}
/**
- * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
+ * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition
* @return type
**/
diff --git a/sdk/src/main/java/com/finbourne/lusid/model/PortfolioWithoutHref.java b/sdk/src/main/java/com/finbourne/lusid/model/PortfolioWithoutHref.java
index 1d7138f4b18..583cce2bc63 100644
--- a/sdk/src/main/java/com/finbourne/lusid/model/PortfolioWithoutHref.java
+++ b/sdk/src/main/java/com/finbourne/lusid/model/PortfolioWithoutHref.java
@@ -67,7 +67,7 @@ public class PortfolioWithoutHref {
private ResourceId id;
/**
* The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
*/
@JsonAdapter(TypeEnum.Adapter.class)
public enum TypeEnum {
@@ -75,7 +75,9 @@ public enum TypeEnum {
REFERENCE("Reference"),
- DERIVEDTRANSACTION("DerivedTransaction");
+ DERIVEDTRANSACTION("DerivedTransaction"),
+
+ SIMPLEPOSITION("SimplePosition");
private String value;
@@ -297,7 +299,7 @@ public PortfolioWithoutHref type(TypeEnum type) {
}
/**
* The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
* @return type
**/
@jakarta.annotation.Nonnull
@@ -67,7 +67,7 @@ public class PortfolioWithoutHref {
private ResourceId id;
/**
- * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
+ * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition
*/
@@ -297,7 +299,7 @@ public PortfolioWithoutHref type(TypeEnum type) {
}
/**
- * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction
+ * The type of the portfolio. The available values are: Transaction, Reference, DerivedTransaction, SimplePosition
* @return type
**/